@@ -138,15 +138,15 @@ void gtkaml_implicits_resolver_resolve (GtkamlImplicitsResolver* self, GtkamlCla
 	gtkaml_implicits_resolver_resolve_complex_attributes (self, class_definition);
 	gtkaml_implicits_resolver_determine_attribute_types (self, class_definition);
 	{
-		GeeIterator* child_it;
-		child_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_children (class_definition));
-		while (gee_iterator_next (child_it)) {
+		GeeIterator* _child_it;
+		_child_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_children (class_definition));
+		while (gee_iterator_next (_child_it)) {
 			GtkamlClassDefinition* child;
-			child = (GtkamlClassDefinition*) gee_iterator_get (child_it);
+			child = (GtkamlClassDefinition*) gee_iterator_get (_child_it);
 			gtkaml_implicits_resolver_resolve (self, child);
 			(child == NULL) ? NULL : (child = (g_object_unref (child), NULL));
 		}
-		(child_it == NULL) ? NULL : (child_it = (gee_collection_object_unref (child_it), NULL));
+		(_child_it == NULL) ? NULL : (_child_it = (gee_collection_object_unref (_child_it), NULL));
 	}
 }
 
@@ -158,11 +158,11 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (class_definition != NULL);
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlAttribute* attr;
-			attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 			if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 				GtkamlAttribute* _tmp0;
 				_tmp0 = NULL;
@@ -170,7 +170,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	_tmp1 = FALSE;
 	if (gtkaml_class_definition_get_construct_method (class_definition) != NULL) {
@@ -180,11 +180,11 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 	}
 	if (_tmp1) {
 		{
-			GeeIterator* attr_it;
-			attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_construct_method (class_definition)));
-			while (gee_iterator_next (attr_it)) {
+			GeeIterator* _attr_it;
+			_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_construct_method (class_definition)));
+			while (gee_iterator_next (_attr_it)) {
 				GtkamlAttribute* attr;
-				attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+				attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					GtkamlAttribute* _tmp2;
 					_tmp2 = NULL;
@@ -192,7 +192,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 				}
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 			}
-			(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+			(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 		}
 	}
 	first = TRUE;
@@ -205,12 +205,12 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 	/*do not generate the first parameter of the container add child method*/
 	if (_tmp3) {
 		{
-			GeeIterator* attr_it;
-			attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_add_method (class_definition)));
-			while (gee_iterator_next (attr_it)) {
+			GeeIterator* _attr_it;
+			_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_add_method (class_definition)));
+			while (gee_iterator_next (_attr_it)) {
 				GtkamlAttribute* attr;
 				gboolean _tmp4;
-				attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+				attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 				_tmp4 = FALSE;
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					_tmp4 = !first;
@@ -225,7 +225,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 				first = FALSE;
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 			}
-			(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+			(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 		}
 	}
 }
@@ -250,22 +250,22 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 	to_remove = (GeeList*) gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 	/*pass one: see if we find an explicitly specified add method*/
 	{
-		GeeIterator* add_it;
+		GeeIterator* _add_it;
 		/*pass one: see if we find an explicitly specified add method*/
-		add_it = gee_iterable_iterator ((GeeIterable*) adds);
+		_add_it = gee_iterable_iterator ((GeeIterable*) adds);
 		/*pass one: see if we find an explicitly specified add method*/
-		while (gee_iterator_next (add_it)) {
+		while (gee_iterator_next (_add_it)) {
 			ValaMethod* add;
 			/*pass one: see if we find an explicitly specified add method*/
-			add = (ValaMethod*) gee_iterator_get (add_it);
+			add = (ValaMethod*) gee_iterator_get (_add_it);
 			{
-				GeeIterator* attr_it;
-				attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (child_definition));
-				while (gee_iterator_next (attr_it)) {
+				GeeIterator* _attr_it;
+				_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (child_definition));
+				while (gee_iterator_next (_attr_it)) {
 					GtkamlAttribute* attr;
 					gboolean _tmp0;
 					gboolean _tmp1;
-					attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+					attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 					_tmp0 = FALSE;
 					_tmp1 = FALSE;
 					if (GTKAML_IS_SIMPLE_ATTRIBUTE (attr)) {
@@ -292,11 +292,11 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 					}
 					(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 				}
-				(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+				(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 			}
 			(add == NULL) ? NULL : (add = (vala_code_node_unref (add), NULL));
 		}
-		(add_it == NULL) ? NULL : (add_it = (gee_collection_object_unref (add_it), NULL));
+		(_add_it == NULL) ? NULL : (_add_it = (gee_collection_object_unref (_add_it), NULL));
 	}
 	first_parameter = gtkaml_complex_attribute_new ("widget", child_definition);
 	method_matcher = gtkaml_method_matcher_new (self->priv->_implicits_store, gtkaml_class_definition_get_parent_container (child_definition), "container add method", first_parameter);
@@ -304,15 +304,15 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 	if (determined_add == NULL) {
 		ValaMethod* _tmp5;
 		{
-			GeeIterator* method_it;
-			method_it = gee_iterable_iterator ((GeeIterable*) adds);
-			while (gee_iterator_next (method_it)) {
+			GeeIterator* _method_it;
+			_method_it = gee_iterable_iterator ((GeeIterable*) adds);
+			while (gee_iterator_next (_method_it)) {
 				ValaMethod* method;
-				method = (ValaMethod*) gee_iterator_get (method_it);
+				method = (ValaMethod*) gee_iterator_get (_method_it);
 				gtkaml_method_matcher_add_method (method_matcher, method);
 				(method == NULL) ? NULL : (method = (vala_code_node_unref (method), NULL));
 			}
-			(method_it == NULL) ? NULL : (method_it = (gee_collection_object_unref (method_it), NULL));
+			(_method_it == NULL) ? NULL : (_method_it = (gee_collection_object_unref (_method_it), NULL));
 		}
 		_tmp5 = NULL;
 		determined_add = (_tmp5 = gtkaml_method_matcher_determine_matching_method (method_matcher), (determined_add == NULL) ? NULL : (determined_add = (vala_code_node_unref (determined_add), NULL)), _tmp5);
@@ -342,15 +342,15 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 	}
 	gtkaml_method_matcher_set_method_parameters (method_matcher, (GtkamlMethod*) new_method, determined_add);
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlAttribute* attr;
-			attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 			gee_collection_remove ((GeeCollection*) gtkaml_class_definition_get_attrs (child_definition), attr);
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	gtkaml_class_definition_set_add_method (child_definition, new_method);
 	(adds == NULL) ? NULL : (adds = (gee_collection_object_unref (adds), NULL));
@@ -376,22 +376,22 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 	to_remove = (GeeList*) gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 	/*pass one: see if we find an explicitly specified constructor*/
 	{
-		GeeIterator* constructor_it;
+		GeeIterator* _constructor_it;
 		/*pass one: see if we find an explicitly specified constructor*/
-		constructor_it = gee_iterable_iterator ((GeeIterable*) constructors);
+		_constructor_it = gee_iterable_iterator ((GeeIterable*) constructors);
 		/*pass one: see if we find an explicitly specified constructor*/
-		while (gee_iterator_next (constructor_it)) {
+		while (gee_iterator_next (_constructor_it)) {
 			ValaMethod* constructor;
 			/*pass one: see if we find an explicitly specified constructor*/
-			constructor = (ValaMethod*) gee_iterator_get (constructor_it);
+			constructor = (ValaMethod*) gee_iterator_get (_constructor_it);
 			{
-				GeeIterator* attr_it;
-				attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
-				while (gee_iterator_next (attr_it)) {
+				GeeIterator* _attr_it;
+				_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
+				while (gee_iterator_next (_attr_it)) {
 					GtkamlAttribute* attr;
 					gboolean _tmp0;
 					gboolean _tmp1;
-					attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+					attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 					_tmp0 = FALSE;
 					_tmp1 = FALSE;
 					if (GTKAML_IS_SIMPLE_ATTRIBUTE (attr)) {
@@ -418,26 +418,26 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 					}
 					(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 				}
-				(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+				(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 			}
 			(constructor == NULL) ? NULL : (constructor = (vala_code_node_unref (constructor), NULL));
 		}
-		(constructor_it == NULL) ? NULL : (constructor_it = (gee_collection_object_unref (constructor_it), NULL));
+		(_constructor_it == NULL) ? NULL : (_constructor_it = (gee_collection_object_unref (_constructor_it), NULL));
 	}
 	method_matcher = gtkaml_method_matcher_new (self->priv->_implicits_store, class_definition, "constructor", NULL);
 	/*pass two: the first who matches the most parameters + warning if there are more*/
 	if (determined_constructor == NULL) {
 		ValaMethod* _tmp5;
 		{
-			GeeIterator* method_it;
-			method_it = gee_iterable_iterator ((GeeIterable*) constructors);
-			while (gee_iterator_next (method_it)) {
+			GeeIterator* _method_it;
+			_method_it = gee_iterable_iterator ((GeeIterable*) constructors);
+			while (gee_iterator_next (_method_it)) {
 				ValaMethod* method;
-				method = (ValaMethod*) gee_iterator_get (method_it);
+				method = (ValaMethod*) gee_iterator_get (_method_it);
 				gtkaml_method_matcher_add_method (method_matcher, method);
 				(method == NULL) ? NULL : (method = (vala_code_node_unref (method), NULL));
 			}
-			(method_it == NULL) ? NULL : (method_it = (gee_collection_object_unref (method_it), NULL));
+			(_method_it == NULL) ? NULL : (_method_it = (gee_collection_object_unref (_method_it), NULL));
 		}
 		_tmp5 = NULL;
 		determined_constructor = (_tmp5 = gtkaml_method_matcher_determine_matching_method (method_matcher), (determined_constructor == NULL) ? NULL : (determined_constructor = (vala_code_node_unref (determined_constructor), NULL)), _tmp5);
@@ -465,15 +465,15 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 	}
 	gtkaml_method_matcher_set_method_parameters (method_matcher, (GtkamlMethod*) new_method, determined_constructor);
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlAttribute* attr;
-			attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 			gee_collection_remove ((GeeCollection*) gtkaml_class_definition_get_attrs (class_definition), attr);
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	gtkaml_class_definition_set_construct_method (class_definition, new_method);
 	(constructors == NULL) ? NULL : (constructors = (gee_collection_object_unref (constructors), NULL));
@@ -516,14 +516,14 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 	}
 	/*recurse over base classes - ugly ugly ugly!*/
 	{
-		GeeIterator* dt_it;
+		GeeIterator* _dt_it;
 		/*recurse over base classes - ugly ugly ugly!*/
-		dt_it = gee_iterable_iterator ((GeeIterable*) base_types);
+		_dt_it = gee_iterable_iterator ((GeeIterable*) base_types);
 		/*recurse over base classes - ugly ugly ugly!*/
-		while (gee_iterator_next (dt_it)) {
+		while (gee_iterator_next (_dt_it)) {
 			ValaDataType* dt;
 			/*recurse over base classes - ugly ugly ugly!*/
-			dt = (ValaDataType*) gee_iterator_get (dt_it);
+			dt = (ValaDataType*) gee_iterator_get (_dt_it);
 			if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 				ValaDataType* _tmp5;
 				char* utns;
@@ -546,26 +546,26 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 			}
 			(dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL));
 		}
-		(dt_it == NULL) ? NULL : (dt_it = (gee_collection_object_unref (dt_it), NULL));
+		(_dt_it == NULL) ? NULL : (_dt_it = (gee_collection_object_unref (_dt_it), NULL));
 	}
 	add_methods = gtkaml_implicits_store_get_adds (self->priv->_implicits_store, ns, vala_symbol_get_name ((ValaSymbol*) container_class_implicits_entry));
 	if (gee_collection_get_size ((GeeCollection*) add_methods) != 0) {
 		{
-			GeeIterator* add_method_it;
-			add_method_it = gee_iterable_iterator ((GeeIterable*) add_methods);
-			while (gee_iterator_next (add_method_it)) {
+			GeeIterator* _add_method_it;
+			_add_method_it = gee_iterable_iterator ((GeeIterable*) add_methods);
+			while (gee_iterator_next (_add_method_it)) {
 				char* add_method;
-				add_method = (char*) gee_iterator_get (add_method_it);
+				add_method = (char*) gee_iterator_get (_add_method_it);
 				{
 					GeeList* _tmp7;
 					GeeIterator* _tmp8;
-					GeeIterator* method_it;
+					GeeIterator* _method_it;
 					_tmp7 = NULL;
 					_tmp8 = NULL;
-					method_it = (_tmp8 = gee_iterable_iterator ((GeeIterable*) (_tmp7 = vala_object_type_symbol_get_methods (container_class_holding_methods))), (_tmp7 == NULL) ? NULL : (_tmp7 = (gee_collection_object_unref (_tmp7), NULL)), _tmp8);
-					while (gee_iterator_next (method_it)) {
+					_method_it = (_tmp8 = gee_iterable_iterator ((GeeIterable*) (_tmp7 = vala_object_type_symbol_get_methods (container_class_holding_methods))), (_tmp7 == NULL) ? NULL : (_tmp7 = (gee_collection_object_unref (_tmp7), NULL)), _tmp8);
+					while (gee_iterator_next (_method_it)) {
 						ValaMethod* method;
-						method = (ValaMethod*) gee_iterator_get (method_it);
+						method = (ValaMethod*) gee_iterator_get (_method_it);
 						if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) method), add_method) == 0) {
 							gee_collection_add ((GeeCollection*) methods, method);
 							/*stderr.printf ("Found direct add method '%s.%s' for %s, we now have %d\n", container_class_holding_methods.name, method.name, container_class_implicits_entry.name, methods.size);*/
@@ -574,11 +574,11 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 						}
 						(method == NULL) ? NULL : (method = (vala_code_node_unref (method), NULL));
 					}
-					(method_it == NULL) ? NULL : (method_it = (gee_collection_object_unref (method_it), NULL));
+					(_method_it == NULL) ? NULL : (_method_it = (gee_collection_object_unref (_method_it), NULL));
 				}
 				add_method = (g_free (add_method), NULL);
 			}
-			(add_method_it == NULL) ? NULL : (add_method_it = (gee_collection_object_unref (add_method_it), NULL));
+			(_add_method_it == NULL) ? NULL : (_add_method_it = (gee_collection_object_unref (_add_method_it), NULL));
 		}
 	}
 	(base_types == NULL) ? NULL : (base_types = (gee_collection_object_unref (base_types), NULL));
@@ -599,16 +599,16 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* dt_it;
+		GeeIterator* _dt_it;
 		/*then recurse over implicits definitions*/
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		dt_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_class_get_base_types (container_class))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_dt_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_class_get_base_types (container_class))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
 		/*then recurse over implicits definitions*/
-		while (gee_iterator_next (dt_it)) {
+		while (gee_iterator_next (_dt_it)) {
 			ValaDataType* dt;
 			/*then recurse over implicits definitions*/
-			dt = (ValaDataType*) gee_iterator_get (dt_it);
+			dt = (ValaDataType*) gee_iterator_get (_dt_it);
 			if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 				ValaDataType* _tmp2;
 				char* utns;
@@ -638,7 +638,7 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 			}
 			(dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL));
 		}
-		(dt_it == NULL) ? NULL : (dt_it = (gee_collection_object_unref (dt_it), NULL));
+		(_dt_it == NULL) ? NULL : (_dt_it = (gee_collection_object_unref (_dt_it), NULL));
 	}
 }
 
@@ -658,24 +658,27 @@ static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicits
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (class_definition != NULL);
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (class_definition));
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlAttribute* attr;
 			ValaMember* _tmp0;
-			attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 			_tmp0 = NULL;
 			gtkaml_attribute_set_target_type (attr, (ValaSymbol*) (_tmp0 = gtkaml_implicits_resolver_member_lookup_inherited (self, gtkaml_class_definition_get_base_type (class_definition), gtkaml_attribute_get_name (attr))));
 			(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
 			if (gtkaml_attribute_get_target_type (attr) == NULL) {
+				char* _tmp2;
 				char* _tmp1;
+				_tmp2 = NULL;
 				_tmp1 = NULL;
-				vala_report_error (gtkaml_class_definition_get_source_reference (class_definition), _tmp1 = g_strdup_printf ("Cannot find member %s of class %s\n", gtkaml_attribute_get_name (attr), gtkaml_class_definition_get_base_full_name (class_definition)));
+				vala_report_error (gtkaml_class_definition_get_source_reference (class_definition), _tmp2 = g_strdup_printf ("Cannot find member %s of class %s\n", gtkaml_attribute_get_name (attr), _tmp1 = gtkaml_class_definition_get_base_full_name (class_definition)));
+				_tmp2 = (g_free (_tmp2), NULL);
 				_tmp1 = (g_free (_tmp1), NULL);
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 }
 
@@ -695,13 +698,13 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 	{
 		GeeList* _tmp2;
 		GeeIterator* _tmp3;
-		GeeIterator* dt_it;
+		GeeIterator* _dt_it;
 		_tmp2 = NULL;
 		_tmp3 = NULL;
-		dt_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_class_get_base_types (clazz))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
-		while (gee_iterator_next (dt_it)) {
+		_dt_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_class_get_base_types (clazz))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
+		while (gee_iterator_next (_dt_it)) {
 			ValaDataType* dt;
-			dt = (ValaDataType*) gee_iterator_get (dt_it);
+			dt = (ValaDataType*) gee_iterator_get (_dt_it);
 			if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 				const char* _tmp5;
 				ValaDataType* _tmp4;
@@ -709,7 +712,7 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 				char* ns;
 				ValaDataType* _tmp6;
 				ValaObjectTypeSymbol* _tmp11;
-				ValaClass* clazz;
+				ValaClass* otherclazz;
 				gboolean _tmp12;
 				_tmp5 = NULL;
 				_tmp4 = NULL;
@@ -730,29 +733,29 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 					ns = (_tmp10 = NULL, ns = (g_free (ns), NULL), _tmp10);
 				}
 				_tmp11 = NULL;
-				clazz = (_tmp11 = gtkaml_implicits_resolver_lookup_class (self, ns, name), VALA_IS_CLASS (_tmp11) ? ((ValaClass*) _tmp11) : NULL);
+				otherclazz = (_tmp11 = gtkaml_implicits_resolver_lookup_class (self, ns, name), VALA_IS_CLASS (_tmp11) ? ((ValaClass*) _tmp11) : NULL);
 				_tmp12 = FALSE;
-				if (clazz != NULL) {
+				if (otherclazz != NULL) {
 					ValaMember* _tmp14;
 					ValaMember* _tmp13;
 					_tmp14 = NULL;
 					_tmp13 = NULL;
-					_tmp12 = (NULL != (result = (_tmp14 = (_tmp13 = gtkaml_implicits_resolver_member_lookup_inherited (self, clazz, member), VALA_IS_MEMBER (_tmp13) ? ((ValaMember*) _tmp13) : NULL), (result == NULL) ? NULL : (result = (vala_code_node_unref (result), NULL)), _tmp14)));
+					_tmp12 = (NULL != (result = (_tmp14 = (_tmp13 = gtkaml_implicits_resolver_member_lookup_inherited (self, otherclazz, member), VALA_IS_MEMBER (_tmp13) ? ((ValaMember*) _tmp13) : NULL), (result == NULL) ? NULL : (result = (vala_code_node_unref (result), NULL)), _tmp14)));
 				} else {
 					_tmp12 = FALSE;
 				}
 				if (_tmp12) {
 					ValaMember* _tmp15;
 					_tmp15 = NULL;
-					return (_tmp15 = result, name = (g_free (name), NULL), ns = (g_free (ns), NULL), (clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (dt_it == NULL) ? NULL : (dt_it = (gee_collection_object_unref (dt_it), NULL)), _tmp15);
+					return (_tmp15 = result, name = (g_free (name), NULL), ns = (g_free (ns), NULL), (otherclazz == NULL) ? NULL : (otherclazz = (vala_code_node_unref (otherclazz), NULL)), (dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL)), (_dt_it == NULL) ? NULL : (_dt_it = (gee_collection_object_unref (_dt_it), NULL)), _tmp15);
 				}
 				name = (g_free (name), NULL);
 				ns = (g_free (ns), NULL);
-				(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
+				(otherclazz == NULL) ? NULL : (otherclazz = (vala_code_node_unref (otherclazz), NULL));
 			}
 			(dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL));
 		}
-		(dt_it == NULL) ? NULL : (dt_it = (gee_collection_object_unref (dt_it), NULL));
+		(_dt_it == NULL) ? NULL : (_dt_it = (gee_collection_object_unref (_dt_it), NULL));
 	}
 	_tmp16 = NULL;
 	return (_tmp16 = NULL, (result == NULL) ? NULL : (result = (vala_code_node_unref (result), NULL)), _tmp16);
@@ -766,15 +769,15 @@ static ValaObjectTypeSymbol* gtkaml_implicits_resolver_lookup_class (GtkamlImpli
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* ns_it;
+		GeeIterator* _ns_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		ns_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context)))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (ns_it)) {
+		_ns_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context)))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_ns_it)) {
 			ValaNamespace* ns;
 			gboolean _tmp2;
 			gboolean _tmp3;
-			ns = (ValaNamespace*) gee_iterator_get (ns_it);
+			ns = (ValaNamespace*) gee_iterator_get (_ns_it);
 			_tmp2 = FALSE;
 			_tmp3 = FALSE;
 			if (vala_symbol_get_name ((ValaSymbol*) ns) == NULL) {
@@ -797,13 +800,13 @@ static ValaObjectTypeSymbol* gtkaml_implicits_resolver_lookup_class (GtkamlImpli
 					_tmp5 = NULL;
 					_tmp4 = NULL;
 					_tmp6 = NULL;
-					return (_tmp6 = (_tmp5 = (_tmp4 = s, VALA_IS_OBJECT_TYPE_SYMBOL (_tmp4) ? ((ValaObjectTypeSymbol*) _tmp4) : NULL), (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (ns_it == NULL) ? NULL : (ns_it = (gee_collection_object_unref (ns_it), NULL)), _tmp6);
+					return (_tmp6 = (_tmp5 = (_tmp4 = s, VALA_IS_OBJECT_TYPE_SYMBOL (_tmp4) ? ((ValaObjectTypeSymbol*) _tmp4) : NULL), (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), _tmp6);
 				}
 				(s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL));
 			}
 			(ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL));
 		}
-		(ns_it == NULL) ? NULL : (ns_it = (gee_collection_object_unref (ns_it), NULL));
+		(_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL));
 	}
 	return NULL;
 }
@@ -817,19 +820,19 @@ static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsRe
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* m_it;
+		GeeIterator* _m_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		m_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_object_type_symbol_get_methods ((ValaObjectTypeSymbol*) clazz))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (m_it)) {
+		_m_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_object_type_symbol_get_methods ((ValaObjectTypeSymbol*) clazz))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_m_it)) {
 			ValaMethod* m;
-			m = (ValaMethod*) gee_iterator_get (m_it);
+			m = (ValaMethod*) gee_iterator_get (_m_it);
 			if (VALA_IS_CREATION_METHOD (m)) {
 				gee_collection_add ((GeeCollection*) constructors, m);
 			}
 			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
 		}
-		(m_it == NULL) ? NULL : (m_it = (gee_collection_object_unref (m_it), NULL));
+		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
 	}
 	return (GeeList*) constructors;
 }
@@ -871,6 +874,7 @@ static void gtkaml_implicits_resolver_set_context (GtkamlImplicitsResolver* self
 
 static void gtkaml_implicits_resolver_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GtkamlImplicitsResolver * self;
+	gpointer boxed;
 	self = GTKAML_IMPLICITS_RESOLVER (object);
 	switch (property_id) {
 		case GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE:
