@@ -90,6 +90,7 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 static gpointer gtkaml_implicits_store_parent_class = NULL;
 static void gtkaml_implicits_store_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -149,8 +150,7 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 			if (inner_error->domain == G_KEY_FILE_ERROR) {
 				goto __catch4_g_key_file_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally4;
 		}
 		return _tmp0;
 	}
@@ -166,7 +166,11 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 		}
 	}
 	__finally4:
-	;
+	if (inner_error != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return FALSE;
+	}
 }
 
 
@@ -178,14 +182,16 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 	inner_error = NULL;
 	{
 		char** _tmp2;
+		gint _tmp1_size;
 		gint _tmp1_length1;
 		gint _tmp0;
 		char** _tmp1;
 		char** _tmp3;
 		_tmp2 = NULL;
-		_tmp1 = (_tmp2 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), _tmp1_length1 = _tmp0, _tmp2);
+		_tmp1 = (_tmp2 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), _tmp1_length1 = _tmp0, _tmp1_size = _tmp1_length1, _tmp2);
 		if (inner_error != NULL) {
 			goto __catch5_g_error;
+			goto __finally5;
 		}
 		_tmp3 = NULL;
 		return (_tmp3 = _tmp1, *result_length1 = _tmp1_length1, _tmp3);
@@ -205,7 +211,11 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 		}
 	}
 	__finally5:
-	;
+	if (inner_error != NULL) {
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return NULL;
+	}
 }
 
 
@@ -295,14 +305,14 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 		GeeArrayList* key_file_list;
 		key_file_list = gee_array_list_new (GTKAML_TYPE_KEY_FILE_WRAPPER, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 		{
-			GeeIterator* implicits_dir_it;
-			implicits_dir_it = gee_iterable_iterator ((GeeIterable*) self->priv->implicits_dirs);
-			while (gee_iterator_next (implicits_dir_it)) {
+			GeeIterator* _implicits_dir_it;
+			_implicits_dir_it = gee_iterable_iterator ((GeeIterable*) self->priv->implicits_dirs);
+			while (gee_iterator_next (_implicits_dir_it)) {
 				char* implicits_dir;
 				char* _tmp1;
 				char* _tmp2;
 				char* file_name;
-				implicits_dir = (char*) gee_iterator_get (implicits_dir_it);
+				implicits_dir = (char*) gee_iterator_get (_implicits_dir_it);
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				file_name = (_tmp2 = g_build_filename (implicits_dir, _tmp1 = g_strconcat (ns, ".implicits", NULL), NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
@@ -313,6 +323,7 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 						g_key_file_load_from_file (key_file_wrapper->key_file, file_name, G_KEY_FILE_NONE, &inner_error);
 						if (inner_error != NULL) {
 							goto __catch6_g_error;
+							goto __finally6;
 						}
 						gee_collection_add ((GeeCollection*) key_file_list, key_file_wrapper);
 					}
@@ -331,13 +342,22 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 						}
 					}
 					__finally6:
-					;
+					if (inner_error != NULL) {
+						(key_file_wrapper == NULL) ? NULL : (key_file_wrapper = (g_object_unref (key_file_wrapper), NULL));
+						implicits_dir = (g_free (implicits_dir), NULL);
+						file_name = (g_free (file_name), NULL);
+						(_implicits_dir_it == NULL) ? NULL : (_implicits_dir_it = (gee_collection_object_unref (_implicits_dir_it), NULL));
+						(key_file_list == NULL) ? NULL : (key_file_list = (gee_collection_object_unref (key_file_list), NULL));
+						g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+						g_clear_error (&inner_error);
+						return NULL;
+					}
 					(key_file_wrapper == NULL) ? NULL : (key_file_wrapper = (g_object_unref (key_file_wrapper), NULL));
 				}
 				implicits_dir = (g_free (implicits_dir), NULL);
 				file_name = (g_free (file_name), NULL);
 			}
-			(implicits_dir_it == NULL) ? NULL : (implicits_dir_it = (gee_collection_object_unref (implicits_dir_it), NULL));
+			(_implicits_dir_it == NULL) ? NULL : (_implicits_dir_it = (gee_collection_object_unref (_implicits_dir_it), NULL));
 		}
 		/*even an empty list does it: so that we don't scan the directories again*/
 		gee_map_set (self->priv->loaded_ns, ns, (GeeList*) key_file_list);
@@ -356,25 +376,26 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 	adds = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
 	kf_ns = gtkaml_implicits_store_get_ns (self, ns);
 	{
-		GeeIterator* kfw_it;
-		kfw_it = gee_iterable_iterator ((GeeIterable*) kf_ns);
-		while (gee_iterator_next (kfw_it)) {
+		GeeIterator* _kfw_it;
+		_kfw_it = gee_iterable_iterator ((GeeIterable*) kf_ns);
+		while (gee_iterator_next (_kfw_it)) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it);
+			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (_kfw_it);
 			if (gtkaml_key_file_wrapper_has_key (kfw, class_name, "adds")) {
 				char** _tmp1;
+				gint kf_adds_size;
 				gint kf_adds_length1;
 				gint _tmp0;
 				char** kf_adds;
 				_tmp1 = NULL;
-				kf_adds = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, "adds", &_tmp0), kf_adds_length1 = _tmp0, _tmp1);
+				kf_adds = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, "adds", &_tmp0), kf_adds_length1 = _tmp0, kf_adds_size = kf_adds_length1, _tmp1);
 				{
 					char** add_collection;
 					int add_collection_length1;
 					int add_it;
 					add_collection = kf_adds;
 					add_collection_length1 = kf_adds_length1;
-					for (add_it = 0; ((kf_adds_length1 != -1) && (add_it < kf_adds_length1)) || ((kf_adds_length1 == -1) && (add_collection[add_it] != NULL)); add_it = add_it + 1) {
+					for (add_it = 0; add_it < kf_adds_length1; add_it = add_it + 1) {
 						const char* _tmp2;
 						char* add;
 						_tmp2 = NULL;
@@ -390,7 +411,7 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 			}
 			(kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL));
 		}
-		(kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL));
+		(_kfw_it == NULL) ? NULL : (_kfw_it = (gee_collection_object_unref (_kfw_it), NULL));
 	}
 	_tmp3 = NULL;
 	return (_tmp3 = adds, (kf_ns == NULL) ? NULL : (kf_ns = (gee_collection_object_unref (kf_ns), NULL)), _tmp3);
@@ -407,50 +428,54 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* kfw_it;
+		GeeIterator* _kfw_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		kfw_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = gtkaml_implicits_store_get_ns (self, ns))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (kfw_it)) {
+		_kfw_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = gtkaml_implicits_store_get_ns (self, ns))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_kfw_it)) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it);
+			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (_kfw_it);
 			if (gtkaml_key_file_wrapper_has_key (kfw, class_name, method_name)) {
 				char** _tmp3;
+				gint kf_parameters_size;
 				gint kf_parameters_length1;
 				gint _tmp2;
 				char** kf_parameters;
-				GeeList* _tmp10;
+				GeeList* _tmp11;
 				_tmp3 = NULL;
-				kf_parameters = (_tmp3 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, method_name, &_tmp2), kf_parameters_length1 = _tmp2, _tmp3);
+				kf_parameters = (_tmp3 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, method_name, &_tmp2), kf_parameters_length1 = _tmp2, kf_parameters_size = kf_parameters_length1, _tmp3);
 				{
 					char** parameter_collection;
 					int parameter_collection_length1;
 					int parameter_it;
 					parameter_collection = kf_parameters;
 					parameter_collection_length1 = kf_parameters_length1;
-					for (parameter_it = 0; ((kf_parameters_length1 != -1) && (parameter_it < kf_parameters_length1)) || ((kf_parameters_length1 == -1) && (parameter_collection[parameter_it] != NULL)); parameter_it = parameter_it + 1) {
-						const char* _tmp9;
+					for (parameter_it = 0; parameter_it < kf_parameters_length1; parameter_it = parameter_it + 1) {
+						const char* _tmp10;
 						char* parameter;
-						_tmp9 = NULL;
-						parameter = (_tmp9 = parameter_collection[parameter_it], (_tmp9 == NULL) ? NULL : g_strdup (_tmp9));
+						_tmp10 = NULL;
+						parameter = (_tmp10 = parameter_collection[parameter_it], (_tmp10 == NULL) ? NULL : g_strdup (_tmp10));
 						{
 							GtkamlImplicitsParameter* implicits_parameter;
-							char** _tmp4;
+							char** _tmp5;
+							gint name_value_size;
 							gint name_value_length1;
+							char** _tmp4;
 							char** name_value;
-							char* _tmp6;
-							const char* _tmp5;
-							char* _tmp8;
-							const char* _tmp7;
+							char* _tmp7;
+							const char* _tmp6;
+							char* _tmp9;
+							const char* _tmp8;
 							implicits_parameter = gtkaml_implicits_parameter_new ();
-							_tmp4 = NULL;
-							name_value = (_tmp4 = g_strsplit (parameter, "=", 0), name_value_length1 = -1, _tmp4);
-							_tmp6 = NULL;
 							_tmp5 = NULL;
-							implicits_parameter->name = (_tmp6 = (_tmp5 = name_value[0], (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), implicits_parameter->name = (g_free (implicits_parameter->name), NULL), _tmp6);
-							_tmp8 = NULL;
+							_tmp4 = NULL;
+							name_value = (_tmp5 = _tmp4 = g_strsplit (parameter, "=", 0), name_value_length1 = _vala_array_length (_tmp4), name_value_size = name_value_length1, _tmp5);
 							_tmp7 = NULL;
-							implicits_parameter->default_value = (_tmp8 = (_tmp7 = name_value[1], (_tmp7 == NULL) ? NULL : g_strdup (_tmp7)), implicits_parameter->default_value = (g_free (implicits_parameter->default_value), NULL), _tmp8);
+							_tmp6 = NULL;
+							implicits_parameter->name = (_tmp7 = (_tmp6 = name_value[0], (_tmp6 == NULL) ? NULL : g_strdup (_tmp6)), implicits_parameter->name = (g_free (implicits_parameter->name), NULL), _tmp7);
+							_tmp9 = NULL;
+							_tmp8 = NULL;
+							implicits_parameter->default_value = (_tmp9 = (_tmp8 = name_value[1], (_tmp8 == NULL) ? NULL : g_strdup (_tmp8)), implicits_parameter->default_value = (g_free (implicits_parameter->default_value), NULL), _tmp9);
 							/*either null or not*/
 							gee_collection_add ((GeeCollection*) parameters, implicits_parameter);
 							parameter = (g_free (parameter), NULL);
@@ -459,12 +484,12 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 						}
 					}
 				}
-				_tmp10 = NULL;
-				return (_tmp10 = parameters, kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, (GDestroyNotify) g_free), NULL), (kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL)), (kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL)), _tmp10);
+				_tmp11 = NULL;
+				return (_tmp11 = parameters, kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, (GDestroyNotify) g_free), NULL), (kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL)), (_kfw_it == NULL) ? NULL : (_kfw_it = (gee_collection_object_unref (_kfw_it), NULL)), _tmp11);
 			}
 			(kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL));
 		}
-		(kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL));
+		(_kfw_it == NULL) ? NULL : (_kfw_it = (gee_collection_object_unref (_kfw_it), NULL));
 	}
 	return parameters;
 }
@@ -504,30 +529,30 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	result_array = gtkaml_implicits_store_get_method_parameters (self, ns, clazz, method_name);
 	if (gee_collection_get_size ((GeeCollection*) result_array) != 0) {
 		{
-			GeeIterator* result_item_it;
-			result_item_it = gee_iterable_iterator ((GeeIterable*) result_array);
-			while (gee_iterator_next (result_item_it)) {
+			GeeIterator* _result_item_it;
+			_result_item_it = gee_iterable_iterator ((GeeIterable*) result_array);
+			while (gee_iterator_next (_result_item_it)) {
 				GtkamlImplicitsParameter* result_item;
-				result_item = (GtkamlImplicitsParameter*) gee_iterator_get (result_item_it);
+				result_item = (GtkamlImplicitsParameter*) gee_iterator_get (_result_item_it);
 				if (result_item->default_value != NULL) {
 				}
 				/*stderr.printf ("default value for %s=<%s>\n", result_item.name, result_item.default_value);*/
 				gee_collection_add ((GeeCollection*) result, result_item);
 				(result_item == NULL) ? NULL : (result_item = (g_object_unref (result_item), NULL));
 			}
-			(result_item_it == NULL) ? NULL : (result_item_it = (gee_collection_object_unref (result_item_it), NULL));
+			(_result_item_it == NULL) ? NULL : (_result_item_it = (gee_collection_object_unref (_result_item_it), NULL));
 		}
 	} else {
 		{
 			GeeList* _tmp4;
 			GeeIterator* _tmp5;
-			GeeIterator* p_it;
+			GeeIterator* _p_it;
 			_tmp4 = NULL;
 			_tmp5 = NULL;
-			p_it = (_tmp5 = gee_iterable_iterator ((GeeIterable*) (_tmp4 = vala_method_get_parameters (method))), (_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL)), _tmp5);
-			while (gee_iterator_next (p_it)) {
+			_p_it = (_tmp5 = gee_iterable_iterator ((GeeIterable*) (_tmp4 = vala_method_get_parameters (method))), (_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL)), _tmp5);
+			while (gee_iterator_next (_p_it)) {
 				ValaFormalParameter* p;
-				p = (ValaFormalParameter*) gee_iterator_get (p_it);
+				p = (ValaFormalParameter*) gee_iterator_get (_p_it);
 				if (!vala_formal_parameter_get_ellipsis (p)) {
 					GtkamlImplicitsParameter* new_implicits_parameter;
 					char* _tmp7;
@@ -546,7 +571,7 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 				}
 				(p == NULL) ? NULL : (p = (vala_code_node_unref (p), NULL));
 			}
-			(p_it == NULL) ? NULL : (p_it = (gee_collection_object_unref (p_it), NULL));
+			(_p_it == NULL) ? NULL : (_p_it = (gee_collection_object_unref (_p_it), NULL));
 		}
 	}
 	_tmp9 = NULL;
@@ -605,20 +630,28 @@ GType gtkaml_implicits_store_get_type (void) {
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
