@@ -123,42 +123,42 @@ void gtkaml_method_matcher_add_method (GtkamlMethodMatcher* self, ValaMethod* me
 
 
 ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher* self) {
-	ValaMethod* _tmp20;
+	ValaMethod* _tmp22;
 	g_return_val_if_fail (self != NULL, NULL);
 	/*stderr.printf ("===%d candidates\n", methods.size);*/
 	{
-		GeeIterator* method_it;
+		GeeIterator* _method_it;
 		/*stderr.printf ("===%d candidates\n", methods.size);*/
-		method_it = gee_iterable_iterator ((GeeIterable*) self->priv->methods);
+		_method_it = gee_iterable_iterator ((GeeIterable*) self->priv->methods);
 		/*stderr.printf ("===%d candidates\n", methods.size);*/
-		while (gee_iterator_next (method_it)) {
+		while (gee_iterator_next (_method_it)) {
 			ValaMethod* method;
 			GeeList* parameters;
 			gint current_matches;
 			gint current_matches_defaulted;
 			GeeList* current_defaulted_parameters;
 			/*stderr.printf ("===%d candidates\n", methods.size);*/
-			method = (ValaMethod*) gee_iterator_get (method_it);
+			method = (ValaMethod*) gee_iterator_get (_method_it);
 			/*stderr.printf ("CANDIDATE %s\n", method.name);*/
 			parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, method);
 			current_matches = 0;
 			current_matches_defaulted = 0;
 			current_defaulted_parameters = (GeeList*) gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 			{
-				GeeIterator* parameter_it;
-				parameter_it = gee_iterable_iterator ((GeeIterable*) parameters);
-				while (gee_iterator_next (parameter_it)) {
+				GeeIterator* _parameter_it;
+				_parameter_it = gee_iterable_iterator ((GeeIterable*) parameters);
+				while (gee_iterator_next (_parameter_it)) {
 					GtkamlImplicitsParameter* parameter;
 					gint flag_current_matches_modified;
-					parameter = (GtkamlImplicitsParameter*) gee_iterator_get (parameter_it);
+					parameter = (GtkamlImplicitsParameter*) gee_iterator_get (_parameter_it);
 					/*stderr.printf ("searching for %s =>", parameter.name); */
 					flag_current_matches_modified = current_matches;
 					{
-						GeeIterator* attr_it;
-						attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters));
-						while (gee_iterator_next (attr_it)) {
+						GeeIterator* _attr_it;
+						_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters));
+						while (gee_iterator_next (_attr_it)) {
 							GtkamlAttribute* attr;
-							attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+							attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 							if (_vala_strcmp0 (parameter->name, gtkaml_attribute_get_name (attr)) == 0) {
 								current_matches++;
 								/*stderr.printf (" .. explicit\n");*/
@@ -167,7 +167,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 							}
 							(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 						}
-						(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+						(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 					}
 					if (flag_current_matches_modified == current_matches) {
 						if (parameter->default_value != NULL) {
@@ -178,7 +178,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 					}
 					(parameter == NULL) ? NULL : (parameter = (g_object_unref (parameter), NULL));
 				}
-				(parameter_it == NULL) ? NULL : (parameter_it = (gee_collection_object_unref (parameter_it), NULL));
+				(_parameter_it == NULL) ? NULL : (_parameter_it = (gee_collection_object_unref (_parameter_it), NULL));
 			}
 			/*stderr.printf (" .. default %s\n", parameter.name);
 			stderr.printf (" .. not found\n");*/
@@ -244,45 +244,51 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 			(parameters == NULL) ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL));
 			(current_defaulted_parameters == NULL) ? NULL : (current_defaulted_parameters = (gee_collection_object_unref (current_defaulted_parameters), NULL));
 		}
-		(method_it == NULL) ? NULL : (method_it = (gee_collection_object_unref (method_it), NULL));
+		(_method_it == NULL) ? NULL : (_method_it = (gee_collection_object_unref (_method_it), NULL));
 	}
 	if (self->priv->max_matches_method == NULL) {
 		if (self->priv->min_param_names == NULL) {
+			char* _tmp11;
 			char* _tmp10;
+			_tmp11 = NULL;
 			_tmp10 = NULL;
-			vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->_class_owning_method), _tmp10 = g_strdup_printf ("The class %s doesn't have %ss\n", gtkaml_class_definition_get_base_full_name (self->priv->_class_owning_method), self->priv->_wording));
+			vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->_class_owning_method), _tmp11 = g_strdup_printf ("The class %s doesn't have %ss\n", _tmp10 = gtkaml_class_definition_get_base_full_name (self->priv->_class_owning_method), self->priv->_wording));
+			_tmp11 = (g_free (_tmp11), NULL);
 			_tmp10 = (g_free (_tmp10), NULL);
 		} else {
 			char* message;
 			gint i;
-			char* _tmp16;
+			char* _tmp18;
+			char* _tmp17;
 			message = g_strdup ("");
 			i = 0;
 			if (self->priv->_first_parameter != NULL) {
 				i = 1;
 			}
 			for (; i < (gee_collection_get_size ((GeeCollection*) self->priv->min_param_names) - 1); i++) {
+				char* _tmp14;
 				char* _tmp13;
-				char* _tmp12;
-				GtkamlImplicitsParameter* _tmp11;
+				GtkamlImplicitsParameter* _tmp12;
+				_tmp14 = NULL;
 				_tmp13 = NULL;
 				_tmp12 = NULL;
-				_tmp11 = NULL;
-				message = (_tmp13 = g_strconcat (message, _tmp12 = (g_strconcat ((_tmp11 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name, ", ", NULL)), NULL), message = (g_free (message), NULL), _tmp13);
-				_tmp12 = (g_free (_tmp12), NULL);
-				(_tmp11 == NULL) ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL));
+				message = (_tmp14 = g_strconcat (message, _tmp13 = (g_strconcat ((_tmp12 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name, ", ", NULL)), NULL), message = (g_free (message), NULL), _tmp14);
+				_tmp13 = (g_free (_tmp13), NULL);
+				(_tmp12 == NULL) ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL));
 			}
 			if (i < gee_collection_get_size ((GeeCollection*) self->priv->min_param_names)) {
-				char* _tmp15;
-				GtkamlImplicitsParameter* _tmp14;
+				char* _tmp16;
+				GtkamlImplicitsParameter* _tmp15;
+				_tmp16 = NULL;
 				_tmp15 = NULL;
-				_tmp14 = NULL;
-				message = (_tmp15 = g_strconcat (message, ((_tmp14 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name), NULL), message = (g_free (message), NULL), _tmp15);
-				(_tmp14 == NULL) ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL));
+				message = (_tmp16 = g_strconcat (message, ((_tmp15 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name), NULL), message = (g_free (message), NULL), _tmp16);
+				(_tmp15 == NULL) ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL));
 			}
-			_tmp16 = NULL;
-			vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->class_owning_parameters), _tmp16 = g_strdup_printf ("NO matching %s found for %s: specify at least: %s\n", self->priv->_wording, gtkaml_class_definition_get_base_full_name (self->priv->_class_owning_method), message));
-			_tmp16 = (g_free (_tmp16), NULL);
+			_tmp18 = NULL;
+			_tmp17 = NULL;
+			vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->class_owning_parameters), _tmp18 = g_strdup_printf ("NO matching %s found for %s: specify at least: %s\n", self->priv->_wording, _tmp17 = gtkaml_class_definition_get_base_full_name (self->priv->_class_owning_method), message));
+			_tmp18 = (g_free (_tmp18), NULL);
+			_tmp17 = (g_free (_tmp17), NULL);
 			message = (g_free (message), NULL);
 		}
 		return NULL;
@@ -291,33 +297,33 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 	}
 	/*Report.warning (class_owning_method.source_reference, "More than one %s matches your definition of %s(%s)\n".printf (wording, class_owning_method.identifier, class_owning_method.base_full_name));*/
 	{
-		GeeIterator* parameter_it;
+		GeeIterator* _parameter_it;
 		/*Report.warning (class_owning_method.source_reference, "More than one %s matches your definition of %s(%s)\n".printf (wording, class_owning_method.identifier, class_owning_method.base_full_name));*/
-		parameter_it = gee_iterable_iterator ((GeeIterable*) self->priv->max_matches_method_defaulted_parameters);
+		_parameter_it = gee_iterable_iterator ((GeeIterable*) self->priv->max_matches_method_defaulted_parameters);
 		/*Report.warning (class_owning_method.source_reference, "More than one %s matches your definition of %s(%s)\n".printf (wording, class_owning_method.identifier, class_owning_method.base_full_name));*/
-		while (gee_iterator_next (parameter_it)) {
+		while (gee_iterator_next (_parameter_it)) {
 			GtkamlImplicitsParameter* parameter;
 			/*Report.warning (class_owning_method.source_reference, "More than one %s matches your definition of %s(%s)\n".printf (wording, class_owning_method.identifier, class_owning_method.base_full_name));*/
-			parameter = (GtkamlImplicitsParameter*) gee_iterator_get (parameter_it);
+			parameter = (GtkamlImplicitsParameter*) gee_iterator_get (_parameter_it);
 			/*stderr.printf ("found default value for %s.%s.%s being <%s>\n", class_owning_method.base_full_name, max_matches_method.name, parameter.name, parameter.default_value);*/
 			if (self->priv->_first_parameter != NULL) {
-				GtkamlSimpleAttribute* _tmp18;
-				_tmp18 = NULL;
-				gtkaml_class_definition_add_attribute (gtkaml_complex_attribute_get_complex_type (self->priv->_first_parameter), (GtkamlAttribute*) (_tmp18 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)));
-				(_tmp18 == NULL) ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL));
+				GtkamlSimpleAttribute* _tmp20;
+				_tmp20 = NULL;
+				gtkaml_class_definition_add_attribute (gtkaml_complex_attribute_get_complex_type (self->priv->_first_parameter), (GtkamlAttribute*) (_tmp20 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)));
+				(_tmp20 == NULL) ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL));
 			} else {
-				GtkamlSimpleAttribute* _tmp19;
-				_tmp19 = NULL;
-				gtkaml_class_definition_add_attribute (self->priv->_class_owning_method, (GtkamlAttribute*) (_tmp19 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)));
-				(_tmp19 == NULL) ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL));
+				GtkamlSimpleAttribute* _tmp21;
+				_tmp21 = NULL;
+				gtkaml_class_definition_add_attribute (self->priv->_class_owning_method, (GtkamlAttribute*) (_tmp21 = gtkaml_simple_attribute_new (parameter->name, parameter->default_value)));
+				(_tmp21 == NULL) ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL));
 			}
 			(parameter == NULL) ? NULL : (parameter = (g_object_unref (parameter), NULL));
 		}
-		(parameter_it == NULL) ? NULL : (parameter_it = (gee_collection_object_unref (parameter_it), NULL));
+		(_parameter_it == NULL) ? NULL : (_parameter_it = (gee_collection_object_unref (_parameter_it), NULL));
 	}
 	/*stderr.printf ("selected '%s'\n", max_matches_method.name);*/
-	_tmp20 = NULL;
-	return (_tmp20 = self->priv->max_matches_method, (_tmp20 == NULL) ? NULL : vala_code_node_ref (_tmp20));
+	_tmp22 = NULL;
+	return (_tmp22 = self->priv->max_matches_method, (_tmp22 == NULL) ? NULL : vala_code_node_ref (_tmp22));
 }
 
 
@@ -337,17 +343,17 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 	/*move the attributes from class definition to add method*/
 	parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, determined_method);
 	{
-		GeeIterator* parameter_it;
-		parameter_it = gee_iterable_iterator ((GeeIterable*) parameters);
-		while (gee_iterator_next (parameter_it)) {
+		GeeIterator* _parameter_it;
+		_parameter_it = gee_iterable_iterator ((GeeIterable*) parameters);
+		while (gee_iterator_next (_parameter_it)) {
 			GtkamlImplicitsParameter* parameter;
-			parameter = (GtkamlImplicitsParameter*) gee_iterator_get (parameter_it);
+			parameter = (GtkamlImplicitsParameter*) gee_iterator_get (_parameter_it);
 			{
-				GeeIterator* attr_it;
-				attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters));
-				while (gee_iterator_next (attr_it)) {
+				GeeIterator* _attr_it;
+				_attr_it = gee_iterable_iterator ((GeeIterable*) gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters));
+				while (gee_iterator_next (_attr_it)) {
 					GtkamlAttribute* attr;
-					attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+					attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 					if (_vala_strcmp0 (parameter->name, gtkaml_attribute_get_name (attr)) == 0) {
 						gee_collection_add ((GeeCollection*) gtkaml_method_get_parameter_attributes (new_method), attr);
 						gee_collection_add ((GeeCollection*) to_remove, attr);
@@ -356,15 +362,16 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 					}
 					(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 				}
-				(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+				(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 			}
 			(parameter == NULL) ? NULL : (parameter = (g_object_unref (parameter), NULL));
 		}
-		(parameter_it == NULL) ? NULL : (parameter_it = (gee_collection_object_unref (parameter_it), NULL));
+		(_parameter_it == NULL) ? NULL : (_parameter_it = (gee_collection_object_unref (_parameter_it), NULL));
 	}
 	i = 0;
 	if (gee_collection_get_size ((GeeCollection*) parameters) != gee_collection_get_size ((GeeCollection*) gtkaml_method_get_parameter_attributes (new_method))) {
 		char* message;
+		char* _tmp6;
 		char* _tmp5;
 		/*stderr.printf ("failed because %d != %d", parameters.size, new_method.parameter_attributes.size + i);*/
 		i = 0;
@@ -392,8 +399,10 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			message = (_tmp4 = g_strconcat (message, ((_tmp3 = (GtkamlImplicitsParameter*) gee_list_get (parameters, i))->name), NULL), message = (g_free (message), NULL), _tmp4);
 			(_tmp3 == NULL) ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL));
 		}
+		_tmp6 = NULL;
 		_tmp5 = NULL;
-		vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->class_owning_parameters), _tmp5 = g_strdup_printf ("No matching %s found for %s: specify at least: %s\n", self->priv->_wording, gtkaml_class_definition_get_base_full_name (self->priv->class_owning_parameters), message));
+		vala_report_error (gtkaml_class_definition_get_source_reference (self->priv->class_owning_parameters), _tmp6 = g_strdup_printf ("No matching %s found for %s: specify at least: %s\n", self->priv->_wording, _tmp5 = gtkaml_class_definition_get_base_full_name (self->priv->class_owning_parameters), message));
+		_tmp6 = (g_free (_tmp6), NULL);
 		_tmp5 = (g_free (_tmp5), NULL);
 		message = (g_free (message), NULL);
 		(to_remove == NULL) ? NULL : (to_remove = (gee_collection_object_unref (to_remove), NULL));
@@ -404,11 +413,11 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 	method_parameters = (GeeCollection*) vala_method_get_parameters (determined_method);
 	i = 0;
 	{
-		GeeIterator* formal_parameter_it;
-		formal_parameter_it = gee_iterable_iterator ((GeeIterable*) method_parameters);
-		while (gee_iterator_next (formal_parameter_it)) {
+		GeeIterator* _formal_parameter_it;
+		_formal_parameter_it = gee_iterable_iterator ((GeeIterable*) method_parameters);
+		while (gee_iterator_next (_formal_parameter_it)) {
 			ValaFormalParameter* formal_parameter;
-			formal_parameter = (ValaFormalParameter*) gee_iterator_get (formal_parameter_it);
+			formal_parameter = (ValaFormalParameter*) gee_iterator_get (_formal_parameter_it);
 			if (!vala_formal_parameter_get_ellipsis (formal_parameter)) {
 				GtkamlAttribute* attr;
 				attr = (GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (new_method), i);
@@ -418,18 +427,18 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			}
 			(formal_parameter == NULL) ? NULL : (formal_parameter = (vala_code_node_unref (formal_parameter), NULL));
 		}
-		(formal_parameter_it == NULL) ? NULL : (formal_parameter_it = (gee_collection_object_unref (formal_parameter_it), NULL));
+		(_formal_parameter_it == NULL) ? NULL : (_formal_parameter_it = (gee_collection_object_unref (_formal_parameter_it), NULL));
 	}
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) to_remove);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlAttribute* attr;
-			attr = (GtkamlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlAttribute*) gee_iterator_get (_attr_it);
 			gee_collection_remove ((GeeCollection*) gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters), attr);
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	(to_remove == NULL) ? NULL : (to_remove = (gee_collection_object_unref (to_remove), NULL));
 	(parameters == NULL) ? NULL : (parameters = (gee_collection_object_unref (parameters), NULL));
@@ -535,6 +544,7 @@ static GObject * gtkaml_method_matcher_constructor (GType type, guint n_construc
 
 static void gtkaml_method_matcher_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GtkamlMethodMatcher * self;
+	gpointer boxed;
 	self = GTKAML_METHOD_MATCHER (object);
 	switch (property_id) {
 		case GTKAML_METHOD_MATCHER_CLASS_OWNING_METHOD:
