@@ -48,6 +48,7 @@ static void gtkaml_parser_real_visit_source_file (ValaCodeVisitor* base, ValaSou
 static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSourceFile* gtkaml_source_file);
 static gpointer gtkaml_parser_parent_class = NULL;
 static void gtkaml_parser_finalize (ValaCodeVisitor* obj);
+static gint _vala_array_length (gpointer array);
 
 
 
@@ -63,23 +64,23 @@ GtkamlParser* gtkaml_parser_new (void) {
 }
 
 
-void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** implicits_directories) {
+void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** implicits_directories, int implicits_directories_length1) {
+	ValaCodeContext* _tmp4;
 	ValaCodeContext* _tmp3;
-	ValaCodeContext* _tmp2;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (context != NULL);
 	if (implicits_directories != NULL) {
 		{
 			char** implicits_dirs_collection;
 			int implicits_dirs_collection_length1;
-			char** implicits_dirs_it;
+			int implicits_dirs_it;
 			implicits_dirs_collection = implicits_directories;
-			implicits_dirs_collection_length1 = -1;
-			for (implicits_dirs_it = implicits_dirs_collection; *implicits_dirs_it != NULL; implicits_dirs_it = implicits_dirs_it + 1) {
+			implicits_dirs_collection_length1 = implicits_directories_length1;
+			for (implicits_dirs_it = 0; implicits_dirs_it < implicits_directories_length1; implicits_dirs_it = implicits_dirs_it + 1) {
 				const char* _tmp0;
 				char* implicits_dirs;
 				_tmp0 = NULL;
-				implicits_dirs = (_tmp0 = *implicits_dirs_it, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+				implicits_dirs = (_tmp0 = implicits_dirs_collection[implicits_dirs_it], (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 				{
 					gtkaml_implicits_store_add_implicits_dir (self->priv->implicits_store, implicits_dirs);
 					implicits_dirs = (g_free (implicits_dirs), NULL);
@@ -88,16 +89,18 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 		}
 	}
 	{
+		char** _tmp1;
 		char** datadir_collection;
 		int datadir_collection_length1;
-		char** datadir_it;
-		datadir_collection = g_get_system_data_dirs ();
-		datadir_collection_length1 = -1;
-		for (datadir_it = datadir_collection; *datadir_it != NULL; datadir_it = datadir_it + 1) {
-			const char* _tmp1;
+		int datadir_it;
+		_tmp1 = NULL;
+		datadir_collection = _tmp1 = g_get_system_data_dirs ();
+		datadir_collection_length1 = _vala_array_length (_tmp1);
+		for (datadir_it = 0; datadir_it < _vala_array_length (_tmp1); datadir_it = datadir_it + 1) {
+			const char* _tmp2;
 			char* datadir;
-			_tmp1 = NULL;
-			datadir = (_tmp1 = *datadir_it, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
+			_tmp2 = NULL;
+			datadir = (_tmp2 = datadir_collection[datadir_it], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2));
 			{
 				char* filename;
 				filename = g_build_filename (datadir, "gtkaml", "implicits", NULL);
@@ -109,9 +112,9 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 			}
 		}
 	}
+	_tmp4 = NULL;
 	_tmp3 = NULL;
-	_tmp2 = NULL;
-	self->priv->context = (_tmp3 = (_tmp2 = context, (_tmp2 == NULL) ? NULL : vala_code_context_ref (_tmp2)), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp3);
+	self->priv->context = (_tmp4 = (_tmp3 = context, (_tmp3 == NULL) ? NULL : vala_code_context_ref (_tmp3)), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp4);
 	vala_parser_parse (VALA_PARSER (self), context);
 }
 
@@ -186,14 +189,20 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 				gboolean _tmp2;
 				_tmp0 = NULL;
 				_tmp1 = NULL;
-				vala_filename = (_tmp1 = g_strconcat (_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), (gulong) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))), ".vala", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+				vala_filename = (_tmp1 = g_strconcat (_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), (gsize) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))), ".vala", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 				g_file_set_contents (vala_filename, vala_contents, -1, &inner_error);
 				if (inner_error != NULL) {
+					vala_filename = (g_free (vala_filename), NULL);
+					(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
+					(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
+					(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
+					(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
+					(code_generator == NULL) ? NULL : (code_generator = (g_object_unref (code_generator), NULL));
+					vala_contents = (g_free (vala_contents), NULL);
 					if (inner_error->domain == G_FILE_ERROR) {
 						goto __catch3_g_file_error;
 					}
-					g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-					g_clear_error (&inner_error);
+					goto __finally3;
 				}
 				vala_source_file_set_filename (gtkaml_source_file, vala_filename);
 				VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file ((ValaCodeVisitor*) VALA_PARSER (self), gtkaml_source_file);
@@ -227,7 +236,11 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			}
 		}
 		__finally3:
-		;
+		if (inner_error != NULL) {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+			return;
+		}
 	} else {
 		char* _tmp3;
 		_tmp3 = NULL;
@@ -276,5 +289,17 @@ GType gtkaml_parser_get_type (void) {
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 
 
