@@ -47,6 +47,7 @@
 
 
 
+static char* string_substring (const char* self, glong offset, glong len);
 struct _GtkamlSAXParserPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _source_file;
@@ -81,10 +82,31 @@ static GObject * gtkaml_sax_parser_constructor (GType type, guint n_construct_pr
 static gpointer gtkaml_sax_parser_parent_class = NULL;
 static void gtkaml_sax_parser_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
 GtkamlSAXParser* gtkaml_sax_parser_construct (GType object_type, ValaCodeContext* context, ValaSourceFile* source_file) {
 	GtkamlSAXParser * self;
 	g_return_val_if_fail (context != NULL, NULL);
@@ -125,8 +147,7 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser*
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch2_g_file_error;
 			}
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+			goto __finally2;
 		}
 	}
 	goto __finally2;
@@ -141,7 +162,12 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser*
 		}
 	}
 	__finally2:
-	;
+	if (inner_error != NULL) {
+		contents = (g_free (contents), NULL);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+		g_clear_error (&inner_error);
+		return NULL;
+	}
 	initial_state = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE, NULL, NULL, NULL);
 	gtkaml_state_stack_push (self->priv->_states, initial_state);
 	gtkaml_sax_parser_start_parsing (self, contents, length);
@@ -179,12 +205,12 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 				/*Frist Tag! - that means, add "using" directives first*/
 				nss = gtkaml_sax_parser_parse_namespaces (self, namespaces, nb_namespaces);
 				{
-					GeeIterator* ns_it;
-					ns_it = gee_iterable_iterator ((GeeIterable*) nss);
-					while (gee_iterator_next (ns_it)) {
+					GeeIterator* _ns_it;
+					_ns_it = gee_iterable_iterator ((GeeIterable*) nss);
+					while (gee_iterator_next (_ns_it)) {
 						XmlNamespace* ns;
 						gboolean _tmp0;
-						ns = (XmlNamespace*) gee_iterator_get (ns_it);
+						ns = (XmlNamespace*) gee_iterator_get (_ns_it);
 						_tmp0 = FALSE;
 						if (NULL == ns->prefix) {
 							_tmp0 = TRUE;
@@ -200,13 +226,14 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 						}
 						if (_tmp0) {
 							char** _tmp2;
+							gint uri_definition_size;
 							gint uri_definition_length1;
 							char** uri_definition;
 							ValaUnresolvedSymbol* _tmp3;
 							ValaUsingDirective* _tmp4;
 							ValaUsingDirective* namespace_reference;
 							_tmp2 = NULL;
-							uri_definition = (_tmp2 = g_strsplit_set (ns->URI, ":", 0), uri_definition_length1 = -1, _tmp2);
+							uri_definition = (_tmp2 = g_strsplit_set (ns->URI, ":", 0), uri_definition_length1 = -1, uri_definition_size = uri_definition_length1, _tmp2);
 							_tmp3 = NULL;
 							_tmp4 = NULL;
 							namespace_reference = (_tmp4 = vala_using_directive_new ((ValaSymbol*) (_tmp3 = vala_unresolved_symbol_new (NULL, "GLib", NULL)), source_reference), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL)), _tmp4);
@@ -223,7 +250,7 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 						}
 						(ns == NULL) ? NULL : (ns = (g_object_unref (ns), NULL));
 					}
-					(ns_it == NULL) ? NULL : (ns_it = (gee_collection_object_unref (ns_it), NULL));
+					(_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL));
 				}
 				_tmp5 = NULL;
 				_tmp6 = NULL;
@@ -423,7 +450,7 @@ void gtkaml_sax_parser_characters (GtkamlSAXParser* self, const char* data, gint
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (data != NULL);
 	state = gtkaml_state_stack_peek (self->priv->_states, 0);
-	value = g_strndup (data, (gulong) len);
+	value = g_strndup (data, (gsize) len);
 	_tmp0 = NULL;
 	stripped_value = (_tmp0 = value, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 	g_strstrip (stripped_value);
@@ -478,11 +505,14 @@ void gtkaml_sax_parser_end_element (GtkamlSAXParser* self, const char* localname
 	}
 	/*check if we were in 'attribute' state but no sub-tags or no text/cdata blocks were encountered*/
 	if (_tmp0) {
+		char* _tmp8;
 		char* _tmp7;
 		ValaSourceReference* _tmp6;
+		_tmp8 = NULL;
 		_tmp7 = NULL;
 		_tmp6 = NULL;
-		vala_report_error (_tmp6 = gtkaml_sax_parser_create_source_reference (self), _tmp7 = g_strdup_printf ("%s is not well defined or is not an attribute of %s", gtkaml_state_get_attribute_name (last_state), gtkaml_class_definition_get_base_full_name (gtkaml_state_get_class_definition (last_state))));
+		vala_report_error (_tmp6 = gtkaml_sax_parser_create_source_reference (self), _tmp8 = g_strdup_printf ("%s is not well defined or is not an attribute of %s", gtkaml_state_get_attribute_name (last_state), _tmp7 = gtkaml_class_definition_get_base_full_name (gtkaml_state_get_class_definition (last_state))));
+		_tmp8 = (g_free (_tmp8), NULL);
 		_tmp7 = (g_free (_tmp7), NULL);
 		(_tmp6 == NULL) ? NULL : (_tmp6 = (vala_source_reference_unref (_tmp6), NULL));
 		gtkaml_sax_parser_stop_parsing (self);
@@ -511,13 +541,13 @@ void gtkaml_sax_parser_cdata_block (GtkamlSAXParser* self, const char* cdata, gi
 				gtkaml_root_class_definition_set_original_first_code_line (root_class, gtkaml_sax_parser_line_number (self));
 			}
 			_tmp2 = NULL;
-			gee_collection_add ((GeeCollection*) gtkaml_root_class_definition_get_code (root_class), _tmp2 = g_strndup (cdata, (gulong) len));
+			gee_collection_add ((GeeCollection*) gtkaml_root_class_definition_get_code (root_class), _tmp2 = g_strndup (cdata, (gsize) len));
 			_tmp2 = (g_free (_tmp2), NULL);
 			(root_class == NULL) ? NULL : (root_class = (g_object_unref (root_class), NULL));
 		} else {
 			char* _tmp3;
 			_tmp3 = NULL;
-			gtkaml_sax_parser_parse_attribute_content_as_text (self, state, _tmp3 = g_strndup (cdata, (gulong) len));
+			gtkaml_sax_parser_parse_attribute_content_as_text (self, state, _tmp3 = g_strndup (cdata, (gsize) len));
 			_tmp3 = (g_free (_tmp3), NULL);
 		}
 		(previous_state == NULL) ? NULL : (previous_state = (g_object_unref (previous_state), NULL));
@@ -631,13 +661,13 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* ns_it;
+		GeeIterator* _ns_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		ns_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context)))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (ns_it)) {
+		_ns_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context)))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_ns_it)) {
 			ValaNamespace* ns;
-			ns = (ValaNamespace*) gee_iterator_get (ns_it);
+			ns = (ValaNamespace*) gee_iterator_get (_ns_it);
 			if (_vala_strcmp0 (xmlNamespace, vala_symbol_get_name ((ValaSymbol*) ns)) == 0) {
 				ValaSymbol* s;
 				s = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) ns), name);
@@ -648,30 +678,33 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 					_tmp3 = NULL;
 					_tmp2 = NULL;
 					_tmp4 = NULL;
-					return (_tmp4 = (_tmp3 = ((_tmp2 = s, VALA_IS_CLASS (_tmp2) ? ((ValaClass*) _tmp2) : NULL)), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (ns_it == NULL) ? NULL : (ns_it = (gee_collection_object_unref (ns_it), NULL)), _tmp4);
+					return (_tmp4 = (_tmp3 = ((_tmp2 = s, VALA_IS_CLASS (_tmp2) ? ((ValaClass*) _tmp2) : NULL)), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), _tmp4);
 				}
 				(s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL));
 			}
 			(ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL));
 		}
-		(ns_it == NULL) ? NULL : (ns_it = (gee_collection_object_unref (ns_it), NULL));
+		(_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL));
 	}
 	return NULL;
 }
 
 
 static char* gtkaml_sax_parser_strip_attribute_hyphens (GtkamlSAXParser* self, const char* attrname) {
-	char** _tmp0;
+	char** _tmp1;
+	gint tokens_size;
 	gint tokens_length1;
+	char** _tmp0;
 	char** tokens;
-	char* _tmp1;
+	char* _tmp2;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (attrname != NULL, NULL);
 	/*see TDWTF, "The Hard Way"*/
-	_tmp0 = NULL;
-	tokens = (_tmp0 = g_strsplit (attrname, "-", 0), tokens_length1 = -1, _tmp0);
 	_tmp1 = NULL;
-	return (_tmp1 = g_strjoinv ("_", tokens), tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL), _tmp1);
+	_tmp0 = NULL;
+	tokens = (_tmp1 = _tmp0 = g_strsplit (attrname, "-", 0), tokens_length1 = _vala_array_length (_tmp0), tokens_size = tokens_length1, _tmp1);
+	_tmp2 = NULL;
+	return (_tmp2 = g_strjoinv ("_", tokens), tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL), _tmp2);
 }
 
 
@@ -689,26 +722,26 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 	root_class_definition = (_tmp2 = gtkaml_root_class_definition_new (_tmp0 = gtkaml_sax_parser_create_source_reference (self), "this", _tmp1 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), clazz, DEFINITION_SCOPE_MAIN_CLASS, NULL), _tmp1 = (g_free (_tmp1), NULL), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_source_reference_unref (_tmp0), NULL)), _tmp2);
 	gtkaml_root_class_definition_set_prefixes_namespaces (root_class_definition, self->priv->_prefixes_namespaces);
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlXmlAttribute* attr;
-			attr = (GtkamlXmlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlXmlAttribute*) gee_iterator_get (_attr_it);
 			if (attr->prefix != NULL) {
 				if (_vala_strcmp0 (attr->prefix, self->gtkaml_prefix) == 0) {
-					GQuark _tmp13;
-					char* _tmp12;
-					_tmp12 = NULL;
-					static GQuark _tmp13_label0 = 0;
-					static GQuark _tmp13_label1 = 0;
-					static GQuark _tmp13_label2 = 0;
-					static GQuark _tmp13_label3 = 0;
-					static GQuark _tmp13_label4 = 0;
-					static GQuark _tmp13_label5 = 0;
-					static GQuark _tmp13_label6 = 0;
-					_tmp12 = attr->localname;
-					_tmp13 = (NULL == _tmp12) ? 0 : g_quark_from_string (_tmp12);
-					if ((_tmp13 == ((0 != _tmp13_label0) ? _tmp13_label0 : (_tmp13_label0 = g_quark_from_static_string ("public")))) || (_tmp13 == ((0 != _tmp13_label1) ? _tmp13_label1 : (_tmp13_label1 = g_quark_from_static_string ("name")))))
+					GQuark _tmp14;
+					char* _tmp13;
+					_tmp13 = NULL;
+					static GQuark _tmp14_label0 = 0;
+					static GQuark _tmp14_label1 = 0;
+					static GQuark _tmp14_label2 = 0;
+					static GQuark _tmp14_label3 = 0;
+					static GQuark _tmp14_label4 = 0;
+					static GQuark _tmp14_label5 = 0;
+					static GQuark _tmp14_label6 = 0;
+					_tmp13 = attr->localname;
+					_tmp14 = (NULL == _tmp13) ? 0 : g_quark_from_string (_tmp13);
+					if ((_tmp14 == ((0 != _tmp14_label0) ? _tmp14_label0 : (_tmp14_label0 = g_quark_from_static_string ("public")))) || (_tmp14 == ((0 != _tmp14_label1) ? _tmp14_label1 : (_tmp14_label1 = g_quark_from_static_string ("name")))))
 					do {
 						if (gtkaml_root_class_definition_get_target_name (root_class_definition) != NULL) {
 							char* _tmp4;
@@ -722,11 +755,11 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 						}
 						gtkaml_root_class_definition_set_target_name (root_class_definition, attr->value);
 						break;
-					} while (0); else if (_tmp13 == ((0 != _tmp13_label2) ? _tmp13_label2 : (_tmp13_label2 = g_quark_from_static_string ("namespace"))))
+					} while (0); else if (_tmp14 == ((0 != _tmp14_label2) ? _tmp14_label2 : (_tmp14_label2 = g_quark_from_static_string ("namespace"))))
 					do {
 						gtkaml_root_class_definition_set_target_namespace (root_class_definition, attr->value);
 						break;
-					} while (0); else if (_tmp13 == ((0 != _tmp13_label3) ? _tmp13_label3 : (_tmp13_label3 = g_quark_from_static_string ("private"))))
+					} while (0); else if (_tmp14 == ((0 != _tmp14_label3) ? _tmp14_label3 : (_tmp14_label3 = g_quark_from_static_string ("private"))))
 					do {
 						ValaSourceReference* _tmp5;
 						_tmp5 = NULL;
@@ -734,7 +767,7 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 						(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_source_reference_unref (_tmp5), NULL));
 						gtkaml_sax_parser_stop_parsing (self);
 						break;
-					} while (0); else if (_tmp13 == ((0 != _tmp13_label4) ? _tmp13_label4 : (_tmp13_label4 = g_quark_from_static_string ("construct"))))
+					} while (0); else if (_tmp14 == ((0 != _tmp14_label4) ? _tmp14_label4 : (_tmp14_label4 = g_quark_from_static_string ("construct"))))
 					do {
 						if (gtkaml_class_definition_get_construct_code ((GtkamlClassDefinition*) root_class_definition) != NULL) {
 							ValaSourceReference* _tmp6;
@@ -745,7 +778,7 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 						}
 						gtkaml_class_definition_set_construct_code ((GtkamlClassDefinition*) root_class_definition, attr->value);
 						break;
-					} while (0); else if (_tmp13 == ((0 != _tmp13_label5) ? _tmp13_label5 : (_tmp13_label5 = g_quark_from_static_string ("preconstruct"))))
+					} while (0); else if (_tmp14 == ((0 != _tmp14_label5) ? _tmp14_label5 : (_tmp14_label5 = g_quark_from_static_string ("preconstruct"))))
 					do {
 						if (gtkaml_class_definition_get_preconstruct_code ((GtkamlClassDefinition*) root_class_definition) != NULL) {
 							ValaSourceReference* _tmp7;
@@ -756,14 +789,17 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 						}
 						gtkaml_class_definition_set_preconstruct_code ((GtkamlClassDefinition*) root_class_definition, attr->value);
 						break;
-					} while (0); else if (_tmp13 == ((0 != _tmp13_label6) ? _tmp13_label6 : (_tmp13_label6 = g_quark_from_static_string ("implements"))))
+					} while (0); else if (_tmp14 == ((0 != _tmp14_label6) ? _tmp14_label6 : (_tmp14_label6 = g_quark_from_static_string ("implements"))))
 					do {
-						char** _tmp8;
+						char** _tmp9;
+						gint implementsv_size;
 						gint implementsv_length1;
+						char** _tmp8;
 						char** implementsv;
-						char* _tmp9;
+						char* _tmp10;
+						_tmp9 = NULL;
 						_tmp8 = NULL;
-						implementsv = (_tmp8 = g_strsplit (attr->value, ",", 0), implementsv_length1 = -1, _tmp8);
+						implementsv = (_tmp9 = _tmp8 = g_strsplit (attr->value, ",", 0), implementsv_length1 = _vala_array_length (_tmp8), implementsv_size = implementsv_length1, _tmp9);
 						{
 							gint i;
 							i = 0;
@@ -771,54 +807,54 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 								g_strstrip (implementsv[i]);
 							}
 						}
-						_tmp9 = NULL;
-						gtkaml_root_class_definition_set_implements (root_class_definition, _tmp9 = g_strjoinv (", ", implementsv));
-						_tmp9 = (g_free (_tmp9), NULL);
+						_tmp10 = NULL;
+						gtkaml_root_class_definition_set_implements (root_class_definition, _tmp10 = g_strjoinv (", ", implementsv));
+						_tmp10 = (g_free (_tmp10), NULL);
 						implementsv = (_vala_array_free (implementsv, implementsv_length1, (GDestroyNotify) g_free), NULL);
 						break;
 					} while (0); else
 					do {
-						char* _tmp11;
-						ValaSourceReference* _tmp10;
+						char* _tmp12;
+						ValaSourceReference* _tmp11;
+						_tmp12 = NULL;
 						_tmp11 = NULL;
-						_tmp10 = NULL;
-						vala_report_warning (_tmp10 = gtkaml_sax_parser_create_source_reference (self), _tmp11 = g_strdup_printf ("Unknown gtkaml attribute '%s'.", attr->localname));
-						_tmp11 = (g_free (_tmp11), NULL);
-						(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_source_reference_unref (_tmp10), NULL));
+						vala_report_warning (_tmp11 = gtkaml_sax_parser_create_source_reference (self), _tmp12 = g_strdup_printf ("Unknown gtkaml attribute '%s'.", attr->localname));
+						_tmp12 = (g_free (_tmp12), NULL);
+						(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_source_reference_unref (_tmp11), NULL));
 						break;
 					} while (0);
 				} else {
-					char* _tmp15;
-					ValaSourceReference* _tmp14;
+					char* _tmp16;
+					ValaSourceReference* _tmp15;
+					_tmp16 = NULL;
 					_tmp15 = NULL;
-					_tmp14 = NULL;
-					vala_report_error (_tmp14 = gtkaml_sax_parser_create_source_reference (self), _tmp15 = g_strdup_printf ("'%s' is the only allowed prefix for attributes. Other attributes must be left unprefixed", self->gtkaml_prefix));
-					_tmp15 = (g_free (_tmp15), NULL);
-					(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_source_reference_unref (_tmp14), NULL));
+					vala_report_error (_tmp15 = gtkaml_sax_parser_create_source_reference (self), _tmp16 = g_strdup_printf ("'%s' is the only allowed prefix for attributes. Other attributes must be left unprefixed", self->gtkaml_prefix));
+					_tmp16 = (g_free (_tmp16), NULL);
+					(_tmp15 == NULL) ? NULL : (_tmp15 = (vala_source_reference_unref (_tmp15), NULL));
 					gtkaml_sax_parser_stop_parsing (self);
 				}
 			} else {
-				char* _tmp16;
-				GtkamlSimpleAttribute* _tmp17;
+				char* _tmp17;
+				GtkamlSimpleAttribute* _tmp18;
 				GtkamlSimpleAttribute* simple_attribute;
-				_tmp16 = NULL;
 				_tmp17 = NULL;
-				simple_attribute = (_tmp17 = gtkaml_simple_attribute_new (_tmp16 = gtkaml_sax_parser_strip_attribute_hyphens (self, attr->localname), attr->value), _tmp16 = (g_free (_tmp16), NULL), _tmp17);
+				_tmp18 = NULL;
+				simple_attribute = (_tmp18 = gtkaml_simple_attribute_new (_tmp17 = gtkaml_sax_parser_strip_attribute_hyphens (self, attr->localname), attr->value), _tmp17 = (g_free (_tmp17), NULL), _tmp18);
 				gtkaml_class_definition_add_attribute ((GtkamlClassDefinition*) root_class_definition, (GtkamlAttribute*) simple_attribute);
 				(simple_attribute == NULL) ? NULL : (simple_attribute = (g_object_unref (simple_attribute), NULL));
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	if (gtkaml_root_class_definition_get_target_name (root_class_definition) == NULL) {
-		char* _tmp19;
-		ValaSourceReference* _tmp18;
+		char* _tmp20;
+		ValaSourceReference* _tmp19;
+		_tmp20 = NULL;
 		_tmp19 = NULL;
-		_tmp18 = NULL;
-		vala_report_error (_tmp18 = gtkaml_sax_parser_create_source_reference (self), _tmp19 = g_strdup_printf ("No class name specified: use %s:name for this", self->gtkaml_prefix));
-		_tmp19 = (g_free (_tmp19), NULL);
-		(_tmp18 == NULL) ? NULL : (_tmp18 = (vala_source_reference_unref (_tmp18), NULL));
+		vala_report_error (_tmp19 = gtkaml_sax_parser_create_source_reference (self), _tmp20 = g_strdup_printf ("No class name specified: use %s:name for this", self->gtkaml_prefix));
+		_tmp20 = (g_free (_tmp20), NULL);
+		(_tmp19 == NULL) ? NULL : (_tmp19 = (vala_source_reference_unref (_tmp19), NULL));
 	}
 	return root_class_definition;
 }
@@ -846,12 +882,12 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 	_tmp0 = NULL;
 	parent_container = (_tmp0 = container_definition, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0));
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlXmlAttribute* attr;
 			gboolean _tmp1;
-			attr = (GtkamlXmlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlXmlAttribute*) gee_iterator_get (_attr_it);
 			_tmp1 = FALSE;
 			if (attr->prefix != NULL) {
 				_tmp1 = _vala_strcmp0 (attr->prefix, self->gtkaml_prefix) == 0;
@@ -951,7 +987,7 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	_tmp19 = FALSE;
 	if (identifier != NULL) {
@@ -1030,23 +1066,24 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 		g_strstrip (reference_stripped);
 		if (g_str_has_prefix (reference_stripped, "{")) {
 			if (g_str_has_suffix (reference_stripped, "}")) {
-				char* _tmp34;
 				char* _tmp33;
-				_tmp34 = NULL;
 				_tmp33 = NULL;
-				gtkaml_class_definition_set_identifier (class_definition, _tmp34 = (_tmp33 = g_utf8_offset_to_pointer (reference_stripped, (glong) 1), g_strndup (_tmp33, g_utf8_offset_to_pointer (_tmp33, g_utf8_strlen (reference_stripped, -1) - 2) - _tmp33)));
-				_tmp34 = (g_free (_tmp34), NULL);
+				gtkaml_class_definition_set_identifier (class_definition, _tmp33 = string_substring (reference_stripped, (glong) 1, g_utf8_strlen (reference_stripped, -1) - 2));
+				_tmp33 = (g_free (_tmp33), NULL);
 			} else {
-				ValaSourceReference* _tmp35;
-				_tmp35 = NULL;
-				vala_report_error (_tmp35 = gtkaml_sax_parser_create_source_reference (self), "'existing' attribute not properly ended");
-				(_tmp35 == NULL) ? NULL : (_tmp35 = (vala_source_reference_unref (_tmp35), NULL));
+				ValaSourceReference* _tmp34;
+				_tmp34 = NULL;
+				vala_report_error (_tmp34 = gtkaml_sax_parser_create_source_reference (self), "'existing' attribute not properly ended");
+				(_tmp34 == NULL) ? NULL : (_tmp34 = (vala_source_reference_unref (_tmp34), NULL));
 			}
 		} else {
 			char* _tmp36;
+			char* _tmp35;
 			_tmp36 = NULL;
-			gtkaml_class_definition_set_identifier (class_definition, _tmp36 = g_strdup_printf ("(%s as %s)", reference, gtkaml_class_definition_get_base_full_name (class_definition)));
+			_tmp35 = NULL;
+			gtkaml_class_definition_set_identifier (class_definition, _tmp36 = g_strdup_printf ("(%s as %s)", reference, _tmp35 = gtkaml_class_definition_get_base_full_name (class_definition)));
 			_tmp36 = (g_free (_tmp36), NULL);
+			_tmp35 = (g_free (_tmp35), NULL);
 		}
 		reference_stripped = (g_free (reference_stripped), NULL);
 	}
@@ -1054,11 +1091,11 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 		gtkaml_class_definition_add_child (container_definition, class_definition);
 	}
 	{
-		GeeIterator* attr_it;
-		attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
-		while (gee_iterator_next (attr_it)) {
+		GeeIterator* _attr_it;
+		_attr_it = gee_iterable_iterator ((GeeIterable*) attrs);
+		while (gee_iterator_next (_attr_it)) {
 			GtkamlXmlAttribute* attr;
-			attr = (GtkamlXmlAttribute*) gee_iterator_get (attr_it);
+			attr = (GtkamlXmlAttribute*) gee_iterator_get (_attr_it);
 			if (attr->prefix == NULL) {
 				char* _tmp37;
 				GtkamlSimpleAttribute* _tmp38;
@@ -1071,7 +1108,7 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
-		(attr_it == NULL) ? NULL : (attr_it = (gee_collection_object_unref (attr_it), NULL));
+		(_attr_it == NULL) ? NULL : (_attr_it = (gee_collection_object_unref (_attr_it), NULL));
 	}
 	_tmp39 = NULL;
 	return (_tmp39 = class_definition, identifier = (g_free (identifier), NULL), reference = (g_free (reference), NULL), construct_code = (g_free (construct_code), NULL), preconstruct_code = (g_free (preconstruct_code), NULL), (parent_container == NULL) ? NULL : (parent_container = (g_object_unref (parent_container), NULL)), _tmp39);
@@ -1120,7 +1157,7 @@ static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char*
 			_tmp8 = NULL;
 			end = (_tmp9 = (_tmp8 = attributes[walker + 4], (_tmp8 == NULL) ? NULL : g_strdup (_tmp8)), end = (g_free (end), NULL), _tmp9);
 			_tmp10 = NULL;
-			attr->value = (_tmp10 = g_strndup (attr->value, (gulong) (g_utf8_strlen (attr->value, -1) - g_utf8_strlen (end, -1))), attr->value = (g_free (attr->value), NULL), _tmp10);
+			attr->value = (_tmp10 = g_strndup (attr->value, (gsize) (g_utf8_strlen (attr->value, -1) - g_utf8_strlen (end, -1))), attr->value = (g_free (attr->value), NULL), _tmp10);
 			gee_collection_add ((GeeCollection*) attribute_list, attr);
 			walker = walker + (5);
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -1164,28 +1201,26 @@ static GeeList* gtkaml_sax_parser_parse_namespaces (GtkamlSAXParser* self, char*
 				if (ns->prefix != NULL) {
 					char* _tmp6;
 					const char* _tmp5;
-					char* _tmp7;
 					char* version;
 					_tmp6 = NULL;
 					_tmp5 = NULL;
 					self->gtkaml_prefix = (_tmp6 = (_tmp5 = ns->prefix, (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), self->gtkaml_prefix = (g_free (self->gtkaml_prefix), NULL), _tmp6);
-					_tmp7 = NULL;
-					version = (_tmp7 = g_utf8_offset_to_pointer (ns->URI, g_utf8_strlen ("http://gtkaml.org/", -1)), g_strndup (_tmp7, g_utf8_offset_to_pointer (_tmp7, g_utf8_strlen (ns->URI, -1) - g_utf8_strlen ("http://gtkaml.org/", -1)) - _tmp7));
+					version = string_substring (ns->URI, g_utf8_strlen ("http://gtkaml.org/", -1), g_utf8_strlen (ns->URI, -1) - g_utf8_strlen ("http://gtkaml.org/", -1));
 					if (_vala_strcmp0 (version, PACKAGE_VERSION) > 0) {
-						char* _tmp9;
-						ValaSourceReference* _tmp8;
-						_tmp9 = NULL;
+						char* _tmp8;
+						ValaSourceReference* _tmp7;
 						_tmp8 = NULL;
-						vala_report_warning (_tmp8 = gtkaml_sax_parser_create_source_reference (self), _tmp9 = g_strdup_printf ("Source file version (%s) newer than gtkaml compiler version (%s)", version, PACKAGE_VERSION));
-						_tmp9 = (g_free (_tmp9), NULL);
-						(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_source_reference_unref (_tmp8), NULL));
+						_tmp7 = NULL;
+						vala_report_warning (_tmp7 = gtkaml_sax_parser_create_source_reference (self), _tmp8 = g_strdup_printf ("Source file version (%s) newer than gtkaml compiler version (%s)", version, PACKAGE_VERSION));
+						_tmp8 = (g_free (_tmp8), NULL);
+						(_tmp7 == NULL) ? NULL : (_tmp7 = (vala_source_reference_unref (_tmp7), NULL));
 					}
 					version = (g_free (version), NULL);
 				} else {
-					ValaSourceReference* _tmp10;
-					_tmp10 = NULL;
-					vala_report_error (_tmp10 = gtkaml_sax_parser_create_source_reference (self), "You cannot use the gtkaml namespace as default namespace");
-					(_tmp10 == NULL) ? NULL : (_tmp10 = (vala_source_reference_unref (_tmp10), NULL));
+					ValaSourceReference* _tmp9;
+					_tmp9 = NULL;
+					vala_report_error (_tmp9 = gtkaml_sax_parser_create_source_reference (self), "You cannot use the gtkaml namespace as default namespace");
+					(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_source_reference_unref (_tmp9), NULL));
 				}
 			}
 			gee_collection_add ((GeeCollection*) namespace_list, ns);
@@ -1301,6 +1336,7 @@ static GObject * gtkaml_sax_parser_constructor (GType type, guint n_construct_pr
 
 static void gtkaml_sax_parser_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	GtkamlSAXParser * self;
+	gpointer boxed;
 	self = GTKAML_SAX_PARSER (object);
 	switch (property_id) {
 		case GTKAML_SAX_PARSER_CONTEXT:
@@ -1379,20 +1415,28 @@ GType gtkaml_sax_parser_get_type (void) {
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
